<?php

namespace Larayellow\Yellowpage\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Larayellow\Yellowpage\Models\Yellowpage;

class YellowpagePolicy
{

    /**
     * Determine if the given user can view the yellowpage.
     *
     * @param UserPolicyInterface $authUser
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Yellowpage $yellowpage)
    {
        if ($authUser->canDo('yellowpage.yellowpage.view') && $authUser->isAdmin()) {
            return true;
        }

        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a yellowpage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('yellowpage.yellowpage.create');
    }

    /**
     * Determine if the given user can update the given yellowpage.
     *
     * @param UserPolicyInterface $authUser
     * @param Yellowpage $yellowpage
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Yellowpage $yellowpage)
    {
        if ($authUser->canDo('yellowpage.yellowpage.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given yellowpage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Yellowpage $yellowpage)
    {
        return $yellowpage->user_id == user_id() && $yellowpage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given yellowpage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Yellowpage $yellowpage)
    {
        if ($authUser->canDo('yellowpage.yellowpage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given yellowpage.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Yellowpage $yellowpage)
    {
        if ($authUser->canDo('yellowpage.yellowpage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
